__version__ = "1.0.2"
__copyright__ = "Divkix <https://github.com/Divkix>"

# Methods to get proxies!
from .package.main import (
    get_all_proxies,
    get_http,
    get_https,
    get_proxy,
    get_socks4,
    get_socks5,
    save_all_proxies,
    save_http,
    save_https,
    save_proxy,
    save_socks4,
    save_socks5,
)
